@@ -41,6 +41,23 @@ test_that("classifyPairs raises error without train/test split", {
     expect_error(classifyPairs(testclassifier, dnosplit), "Need data with train/test split!")
 })
 
+test_that("classifyPairs works with three algorithms", {
+    res = classifyPairs(classifier=idtestclassifier, d.three)
+    expect_equal(unique(res$predictions$id), 11:20)
+    by(res$predictions, res$predictions$id, function(ss) {
+        expect_equal(ss$algorithm, factor(c("b", "c", "d")))
+        expect_equal(ss$score, c(2, 1, 0))
+    })
+
+    fold$id = 1:10
+    preds = res$predictor(fold)
+    expect_equal(unique(preds$id), 1:10)
+    by(preds, preds$id, function(ss) {
+        expect_equal(ss$algorithm, factor(c("b", "c", "d")))
+        expect_equal(ss$score, c(2, 1, 0))
+    })
+})
+
 test_that("classifyPairs respects minimize", {
     res = classifyPairs(classifier=idtestclassifier, d)
     expect_equal(unique(res$predictions$id), 11:20)
@@ -80,14 +97,14 @@ test_that("classifyPairs works with NA predictions", {
     expect_equal(unique(res$predictions$id), 11:20)
     by(res$predictions, res$predictions$id, function(ss) {
         expect_equal(ss$algorithm, factor(c("b", "c")))
-        expect_equal(ss$score, as.numeric(c(NA, NA)))
+        expect_equal(ss$score, c(0, 0))
     })
     fold$id = 1:10
     preds = res$predictor(fold)
     expect_equal(unique(preds$id), 1:10)
     by(preds, preds$id, function(ss) {
         expect_equal(ss$algorithm, factor(c("b", "c")))
-        expect_equal(ss$score, as.numeric(c(NA, NA)))
+        expect_equal(ss$score, c(0, 0))
     })
 
     res = classifyPairs(classifier=natestclassifier, combine=natestclassifier, d)
@@ -104,8 +121,8 @@ test_that("classifyPairs works with one class train data", {
     res = classifyPairs(classifier=makeLearner("classif.rpart"), one)
     expect_equal(unique(res$predictions$id), 11:20)
     by(res$predictions, res$predictions$id, function(ss) {
-        expect_equal(ss$algorithm, factor(c("a")))
-        expect_equal(ss$score, c(1))
+        expect_equal(ss$algorithm, factor(c("a", "c", "b")))
+        expect_equal(ss$score, c(2, 1, 0))
     })
 })
 
